# Energystats 

Energystats is a python library indending to implement the basic building tools of energy-statistics-based methods, 
which is a collection of non-parametric statistical methods that usually do not assume anything beyond the existence of the first and second moments.
For more information refer to Szekely and Rizzo[2023].


# Getting started

Energystats is on PyPi, you can download and install the package using 

```pip install energystats```

